@@ -30,6 +30,7 @@ from pdm.formats import FORMATS
 from pdm.formats.base import array_of_inline_tables, make_array, make_inline_table
 from pdm.installers.installers import format_dist
 from pdm.models.candidates import Candidate
+from pdm.models.pip_shims import FrozenRequirement
 from pdm.models.python import PythonInfo
 from pdm.models.requirements import Requirement, parse_requirement, strip_extras
 from pdm.models.specifiers import get_specifier
@@ -161,7 +162,7 @@ def do_sync(
         clean,
         dry_run,
         no_editable=no_editable,
-        install_self=not no_self and "default" in sections,
+        install_self=not no_self and "default" in sections and bool(project.meta.name),
     )
     handler.synchronize()
 
@@ -175,6 +176,7 @@ def do_add(
     strategy: str = "reuse",
     editables: Iterable[str] = (),
     packages: Iterable[str] = (),
+    unconstrained: bool = False,
     no_editable: bool = False,
     no_self: bool = False,
 ) -> None:
@@ -197,13 +199,18 @@ def do_add(
         + ", ".join(termui.green(key or "", bold=True) for key in requirements)
     )
     all_dependencies = project.all_dependencies
-    all_dependencies.setdefault(section, {}).update(requirements)
+    section_deps = all_dependencies.setdefault(section, {})
+    if unconstrained:
+        for req in section_deps.values():
+            req.specifier = get_specifier("")
+    section_deps.update(requirements)
     reqs = [r for deps in all_dependencies.values() for r in deps.values()]
     resolved = do_lock(project, strategy, tracked_names, reqs)
 
     # Update dependency specifiers and lockfile hash.
-    save_version_specifiers({section: requirements}, resolved, save)
-    project.add_dependencies(requirements, section, dev)
+    deps_to_update = section_deps if unconstrained else requirements
+    save_version_specifiers({section: deps_to_update}, resolved, save)
+    project.add_dependencies(deps_to_update, section, dev)
     lockfile = project.lockfile
     project.write_lockfile(lockfile, False)
 
@@ -356,19 +363,17 @@ def do_remove(
         )
 
 
-def do_list(project: Project, graph: bool = False, reverse: bool = False) -> None:
-    """Display a list of packages installed in the local packages directory.
-
-    :param project: the project instance.
-    :param graph: whether to display a graph.
-    :param reverse: whether to display reverse graph.
-    """
+def do_list(
+    project: Project,
+    graph: bool = False,
+    reverse: bool = False,
+    freeze: bool = False,
+) -> None:
+    """Display a list of packages installed in the local packages directory."""
     from pdm.cli.utils import build_dependency_graph, format_dependency_graph
 
     check_project_file(project)
     working_set = project.environment.get_working_set()
-    if reverse and not graph:
-        raise PdmUsageError("--reverse must be used with --graph")
     if graph:
         with project.environment.activate():
             dep_graph = build_dependency_graph(working_set)
@@ -376,6 +381,15 @@ def do_list(project: Project, graph: bool = False, reverse: bool = False) -> Non
             format_dependency_graph(project, dep_graph, reverse=reverse)
         )
     else:
+        if reverse:
+            raise PdmUsageError("--reverse must be used with --graph")
+        if freeze:
+            reqs = [
+                str(FrozenRequirement.from_dist(dist))
+                for dist in sorted(working_set.values(), key=lambda d: d.project_name)
+            ]
+            project.core.ui.echo("".join(reqs))
+            return
         rows = [
             (termui.green(k, bold=True), format_dist(v))
             for k, v in sorted(working_set.items())
@@ -392,7 +406,7 @@ def do_build(
     config_settings: Mapping[str, str] | None = None,
 ) -> None:
     """Build artifacts for distribution."""
-    from pdm.builders import EnvSdistBuilder, EnvWheelBuilder
+    from pdm.builders import SdistBuilder, WheelBuilder
 
     if project.is_global:
         raise ProjectError("Not allowed to build based on the global project.")
@@ -406,13 +420,13 @@ def do_build(
     with project.core.ui.logging("build"):
         if sdist:
             project.core.ui.echo("Building sdist...")
-            loc = EnvSdistBuilder(project.root, project.environment).build(
+            loc = SdistBuilder(project.root, project.environment).build(
                 dest, config_settings
             )
             project.core.ui.echo(f"Built sdist at {loc}")
         if wheel:
             project.core.ui.echo("Building wheel...")
-            loc = EnvWheelBuilder(project.root, project.environment).build(
+            loc = WheelBuilder(project.root, project.environment).build(
                 dest, config_settings
             )
             project.core.ui.echo(f"Built wheel at {loc}")
