@@ -1,4 +1,5 @@
 import argparse
+from argparse import _SubParsersAction
 from typing import List, Optional
 
 from pdm.cli.options import Option, global_option, project_option, verbose_option
@@ -23,13 +24,15 @@ class BaseCommand:
         self.add_arguments(parser)
 
     @classmethod
-    def register_to(cls, subparsers, name=None):
+    def register_to(
+        cls, subparsers: _SubParsersAction, name: Optional[str] = None
+    ) -> None:
         """Register a subcommand to the subparsers,
         with an optional name of the subcommand.
         """
         help_text = cls.description or cls.__doc__
         parser = subparsers.add_parser(
-            name or cls.name,
+            name or cls.name or "",
             description=help_text,
             help=help_text,
             formatter_class=PdmFormatter,
