@@ -1,5 +1,12 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, List
+
 from pdm import termui
 
+if TYPE_CHECKING:
+    from pdm.models.candidates import Candidate
+
 
 class PdmException(Exception):
     pass
@@ -21,12 +28,12 @@ class CorruptedCacheError(PdmException):
     pass
 
 
-class PackageIndexError(PdmException):
+class CandidateNotFound(PdmException):
     pass
 
 
 class CandidateInfoNotFound(PdmException):
-    def __init__(self, candidate):
+    def __init__(self, candidate: Candidate) -> None:
         message = (
             "No metadata information is available for "
             f"{termui.green(str(candidate))}."
@@ -36,15 +43,15 @@ class CandidateInfoNotFound(PdmException):
 
 
 class ExtrasError(UserWarning):
-    def __init__(self, extras):
+    def __init__(self, extras: List[str]) -> None:
         super().__init__()
         self.extras = tuple(extras)
 
-    def __str__(self):
+    def __str__(self) -> str:
         return f"Extras not found: {self.extras}"
 
 
-class ProjectError(PdmException):
+class ProjectError(PdmUsageError):
     pass
 
 
@@ -53,7 +60,7 @@ class InstallationError(PdmException):
 
 
 class NoConfigError(PdmException, KeyError):
-    def __init__(self, key):
+    def __init__(self, key: str) -> None:
         super().__init__("No such config item: {}".format(key))
 
 
