@@ -9,9 +9,8 @@ import sys
 import sysconfig
 import tempfile
 from contextlib import contextmanager
-from os import PathLike
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Dict, Generator, Iterator, List, Optional
+from typing import TYPE_CHECKING, Any, Generator, Iterator
 
 from distlib.scripts import ScriptMaker
 from pip._vendor import packaging, pkg_resources
@@ -26,31 +25,20 @@ from pdm.models.in_process import (
     get_sys_config_paths,
 )
 from pdm.models.pip_shims import misc, patch_bin_prefix, req_uninstall
-from pdm.utils import (
-    allow_all_wheels,
-    cached_property,
-    convert_hashes,
-    create_tracked_tempdir,
-    expand_env_vars_in_auth,
-    get_finder,
-    populate_link,
-    temp_environ,
-)
+from pdm.utils import cached_property, expand_env_vars_in_auth, get_finder, temp_environ
 
 if TYPE_CHECKING:
     from pdm._types import Source
     from pdm.models.python import PythonInfo
     from pdm.project import Project
 
-_egg_info_re = re.compile(r"([a-z0-9_.]+)-([a-z0-9_.!+-]+)", re.IGNORECASE)
-
 
 class WorkingSet(collections.abc.Mapping):
     """A dict-like class that holds all installed packages in the lib directory."""
 
     def __init__(
         self,
-        paths: Optional[List[str]] = None,
+        paths: list[str] | None = None,
         python: str = pkg_resources.PY_MAJOR,
     ):
         self.env = pkg_resources.Environment(paths, python=python)
@@ -70,7 +58,7 @@ class WorkingSet(collections.abc.Mapping):
     def __iter__(self) -> Iterator[str]:
         return iter(self.env)
 
-    def __add_editable_dists(self):
+    def __add_editable_dists(self) -> None:
         """Editable distributions are not present in pkg_resources.WorkingSet,
         Get them from self.env
         """
@@ -96,7 +84,7 @@ class Environment:
             self.project.sources, self.project.core.ui.verbosity >= termui.DETAIL
         )
 
-    def get_paths(self) -> Dict[str, str]:
+    def get_paths(self) -> dict[str, str]:
         """Get paths like ``sysconfig.get_paths()`` for installation."""
         paths = sysconfig.get_paths()
         scripts = "Scripts" if os.name == "nt" else "bin"
@@ -120,7 +108,7 @@ class Environment:
         with temp_environ():
             working_set = self.get_working_set()
             _old_ws = pkg_resources.working_set
-            pkg_resources.working_set = working_set.pkg_ws
+            pkg_resources.working_set = working_set.pkg_ws  # type: ignore
             # HACK: Replace the is_local with environment version so that packages can
             # be removed correctly.
             _old_sitepackages = misc.site_packages
@@ -129,18 +117,18 @@ class Environment:
             misc.is_local = req_uninstall.is_local = self.is_local
             _evaluate_marker = pkg_resources.evaluate_marker
             pkg_resources.evaluate_marker = self.evaluate_marker
-            sys._original_executable = sys.executable
+            sys._original_executable = sys.executable  # type: ignore
             sys.executable = self.interpreter.executable
             with patch_bin_prefix(paths["scripts"]):
                 yield
-            sys.executable = sys._original_executable
-            del sys._original_executable
+            sys.executable = sys._original_executable  # type: ignore
+            del sys._original_executable  # type: ignore
             pkg_resources.evaluate_marker = _evaluate_marker
             misc.is_local = req_uninstall.is_local = _is_local
             misc.site_packages = _old_sitepackages
             pkg_resources.working_set = _old_ws
 
-    def is_local(self, path: PathLike) -> bool:
+    def is_local(self, path: str) -> bool:
         """PEP 582 version of ``is_local()`` function."""
         return misc.normalize_path(path).startswith(
             misc.normalize_path(self.packages_path.as_posix())
@@ -153,7 +141,11 @@ class Environment:
     @cached_property
     def packages_path(self) -> Path:
         """The local packages path."""
-        pypackages = self.project.root / "__pypackages__" / self.interpreter.identifier
+        pypackages = (
+            self.project.root  # type: ignore
+            / "__pypackages__"
+            / self.interpreter.identifier
+        )
         if not pypackages.exists() and "-32" in pypackages.name:
             compatible_packages = pypackages.with_name(pypackages.name[:-3])
             if compatible_packages.exists():
@@ -166,29 +158,10 @@ class Environment:
             pypackages.joinpath(subdir).mkdir(exist_ok=True, parents=True)
         return pypackages
 
-    def _get_build_dir(self, ireq: pip_shims.InstallRequirement) -> str:
-        if ireq.editable:
-            return ireq.source_dir or self._get_source_dir()
-        else:
-            return create_tracked_tempdir(prefix="pdm-build-")
-
-    def _get_source_dir(self) -> str:
-        packages_dir = self.packages_path
-        if packages_dir:
-            src_dir = packages_dir / "src"
-            src_dir.mkdir(exist_ok=True)
-            return src_dir.as_posix()
-        venv = os.environ.get("VIRTUAL_ENV", None)
-        if venv:
-            src_dir = os.path.join(venv, "src")
-            if os.path.exists(src_dir):
-                return src_dir
-        return create_tracked_tempdir(prefix="pdm-src-")
-
     @contextmanager
     def get_finder(
         self,
-        sources: Optional[List[Source]] = None,
+        sources: list[Source] | None = None,
         ignore_requires_python: bool = False,
     ) -> Generator[pip_shims.PackageFinder, None, None]:
         """Return the package finder of given index sources.
@@ -211,97 +184,9 @@ class Environment:
             ignore_requires_python,
         )
         # Reuse the auth across sessions to avoid prompting repeatly.
-        finder.session.auth = self.auth
+        finder.session.auth = self.auth  # type: ignore
         yield finder
-        finder.session.close()
-
-    def build(
-        self,
-        ireq: pip_shims.InstallRequirement,
-        hashes: Optional[Dict[str, str]] = None,
-        allow_all: bool = True,
-    ) -> str:
-        """Build egg_info directory for editable candidates and a wheel for others.
-
-        :param ireq: the InstallRequirment of the candidate.
-        :param hashes: a dictionary of filename: hash_value to check against downloaded
-        artifacts.
-        :param allow_all: Allow building incompatible wheels.
-        :returns: The full path of the built artifact.
-        """
-        from pdm.builders import EnvEggInfoBuilder, EnvWheelBuilder
-
-        build_dir = self._get_build_dir(ireq)
-        wheel_cache = self.project.make_wheel_cache()
-        supported_tags = pip_shims.get_supported(self.interpreter.for_tag())
-        if hashes:
-            ireq.hash_options = convert_hashes(hashes)
-        with self.get_finder(ignore_requires_python=True) as finder:
-            with allow_all_wheels(allow_all):
-                # temporarily allow all wheels to get a link.
-                populate_link(finder, ireq, False)
-            if hashes is None and not ireq.editable:
-                # If hashes are not given and cache is hit, replace the link with the
-                # cached one. This can speed up by skipping the download and build.
-                cache_entry = wheel_cache.get_cache_entry(
-                    ireq.link,
-                    ireq.req.project_name,
-                    supported_tags,
-                )
-                if cache_entry is not None:
-                    termui.logger.debug("Using cached wheel link: %s", cache_entry.link)
-                    ireq.link = cache_entry.link
-            if not ireq.editable and not ireq.req.name:
-                ireq.source_dir = build_dir
-            else:
-                ireq.ensure_has_source_dir(build_dir)
-
-            if not (ireq.editable and ireq.req.is_local_dir):
-                downloader = pip_shims.Downloader(finder.session, "off")
-                downloaded = pip_shims.unpack_url(
-                    ireq.link,
-                    ireq.source_dir,
-                    downloader,
-                    hashes=ireq.hashes(False),
-                )
-
-                if ireq.link.is_wheel:
-                    # If the file is a wheel, return the downloaded file directly.
-                    return downloaded.path
-
-        # Check the built wheel cache again after hashes are resolved.
-        if not ireq.editable:
-            cache_entry = wheel_cache.get_cache_entry(
-                ireq.link,
-                ireq.req.project_name,
-                supported_tags,
-            )
-            if cache_entry is not None:
-                termui.logger.debug("Using cached wheel link: %s", cache_entry.link)
-                return cache_entry.link.file_path
-
-        # Otherwise, as all source is already prepared, build it.
-        if ireq.editable:
-            builder = EnvEggInfoBuilder(ireq.unpacked_source_directory, self)
-            ret = ireq.metadata_directory = builder.build(build_dir)
-            return ret
-        should_cache = False
-        if ireq.link.is_vcs:
-            vcs = pip_shims.VcsSupport()
-            vcs_backend = vcs.get_backend_for_scheme(ireq.link.scheme)
-            if vcs_backend.is_immutable_rev_checkout(ireq.link.url, ireq.source_dir):
-                should_cache = True
-        elif not ireq.link.is_existing_dir:
-            base, _ = ireq.link.splitext()
-            if _egg_info_re.search(base) is not None:
-                # Determine whether the string looks like an egg_info.
-                should_cache = True
-        output_dir = (
-            wheel_cache.get_path_for_link(ireq.link) if should_cache else build_dir
-        )
-        if not os.path.exists(output_dir):
-            os.makedirs(output_dir, exist_ok=True)
-        return EnvWheelBuilder(ireq.unpacked_source_directory, self).build(output_dir)
+        finder.session.close()  # type: ignore
 
     def get_working_set(self) -> WorkingSet:
         """Get the working set based on local packages directory."""
@@ -312,11 +197,11 @@ class Environment:
         )
 
     @cached_property
-    def marker_environment(self) -> Dict[str, Any]:
+    def marker_environment(self) -> dict[str, Any]:
         """Get environment for marker evaluation"""
         return get_pep508_environment(self.interpreter.executable)
 
-    def which(self, command: str) -> str:
+    def which(self, command: str) -> str | None:
         """Get the full path of the given executable against this environment."""
         if not os.path.isabs(command) and command.startswith("python"):
             python = os.path.splitext(command)[0]
@@ -343,7 +228,7 @@ class Environment:
                 re.sub(rb"#!.+?python.*?$", shebang, child.read_bytes(), flags=re.M)
             )
 
-    def _download_pip_wheel(self, path: os.PathLike):
+    def _download_pip_wheel(self, path: str | Path) -> None:
         dirname = Path(tempfile.mkdtemp(prefix="pip-download-"))
         try:
             subprocess.check_call(
@@ -366,7 +251,7 @@ class Environment:
             shutil.rmtree(dirname, ignore_errors=True)
 
     @cached_property
-    def pip_command(self) -> List[str]:
+    def pip_command(self) -> list[str]:
         """Get a pip command for this environment, and download one if not available.
         Return a list of args like ['python', '-m', 'pip']
         """
@@ -395,17 +280,17 @@ class GlobalEnvironment(Environment):
 
     is_global = True
 
-    def get_paths(self) -> Dict[str, str]:
+    def get_paths(self) -> dict[str, str]:
         paths = get_sys_config_paths(self.interpreter.executable)
         paths["prefix"] = paths["data"]
         paths["headers"] = paths["include"]
         return paths
 
-    def is_local(self, path: PathLike) -> bool:
+    def is_local(self, path: str) -> bool:
         return misc.normalize_path(path).startswith(
             misc.normalize_path(self.get_paths()["prefix"])
         )
 
     @property
-    def packages_path(self) -> Optional[Path]:
+    def packages_path(self) -> Path | None:  # type: ignore
         return None
