@@ -73,6 +73,11 @@ class MockVersionControl(versioncontrol.VersionControl):
     def get_revision(cls, location):
         return "1234567890abcdef"
 
+    def is_immutable_rev_checkout(self, url: str, dest: str) -> bool:
+        if "@1234567890abcdef" in url:
+            return True
+        return super().is_immutable_rev_checkout(url, dest)
+
 
 class _FakeLink:
     is_wheel = False
@@ -150,11 +155,14 @@ main.project_class = TestProject
 
 class Distribution:
     def __init__(self, key, version, editable=False):
-        self.key = key
+        self.key = self.project_name = key
         self.version = version
         self.editable = editable
         self.dependencies = []
 
+    def as_req(self):
+        return f"{self.key}=={self.version}\n"
+
     def requires(self, extras=()):
         return self.dependencies
 
